==> dev.biuro-1.14.0.tar.gz: dev.biuro-1.14.0/wp-content/themes/biuro/searchform.php <==
<?php
/**
 * Template for displaying search form in Biuro
 *
 * @package WordPress
 * @subpackage Biuro
 * @since 1.0
 * @version 1.0
 */

global $query_string;

wp_parse_str( $query_string, $searchQuery );

if ( get_post_type() == 'page'  ):
    $pageTerms = getPageTerm(get_post_custom_keys());

    if ($pageTerms):
        if ($pageTerms->taxonomy === 'type' || $pageTerms->taxonomy === 'field'):
            $searchQuery['s'] = $pageTerms->name;
        elseif ($pageTerms->taxonomy === 'city'):
            $searchQuery['city'] = $pageTerms->name;
        endif;
    endif;

endif;


$langs = pll_the_languages(array('raw'=>1));
$langID = $langs[pll_current_language('slug')]['id'];
?>
<form id="search" class="c-search" action="<?php echo home_url(); ?>" method="get">

    <label for="search-city" class="c-search--col c-search--col-location">
        <svg xmlns="http://www.w3.org/2000/svg" width="15px" height="21px" viewBox="0 0 15 21" class="c-ico--location">
            <path fill="#B8BCC1" d="M7.5,4.25c2.068,0,3.75,1.682,3.75,3.75s-1.682,3.75-3.75,3.75S3.75,10.068,3.75,8 S5.432,4.25,7.5,4.25z M7.5,10.5C8.878,10.5,10,9.379,10,8S8.878,5.5,7.5,5.5C6.121,5.5,5,6.622,5,8C5,9.379,6.121,10.5,7.5,10.5z M7.5,0.5C11.642,0.5,15,3.858,15,8c0,3.024-1.054,3.868-6.729,12.096c-0.373,0.538-1.169,0.538-1.542,0C1.054,11.868,0,11.024,0,8 C0,3.858,3.358,0.5,7.5,0.5z M7.5,19.013c5.442-7.87,6.25-8.494,6.25-11.013c0-1.669-0.65-3.239-1.831-4.419 C10.739,2.4,9.169,1.75,7.5,1.75S4.261,2.4,3.081,3.581C1.9,4.761,1.25,6.331,1.25,8C1.25,10.519,2.059,11.144,7.5,19.013z"/>
        </svg>
        <datalist id="search-cities">
<?php
            foreach ( getOptions('city') as $r ):
?>
                <option value="<?php echo $r['name']; ?>"><?php echo $r['name']; ?> (<?php echo $r['total']; ?>)</option>
<?php
            endforeach;
?>
        </datalist>
        <input list="search-cities" id="search-city" data-id="<?php echo $langID; ?>" aria-label="<?php _e('Locations', 'biuro'); ?>" name="city" value="<?php echo (isset($searchQuery['city'])) ? trim(urldecode($searchQuery['city'])) : ''; ?>" placeholder="<?php _e('Locations', 'biuro'); ?>" class="c-search--input c-search--location" />
        <span class="js-clear--search-city c-search--ico-clear <?php if (!isset($searchQuery['city'])): ?>u-hidden<?php endif; ?>">
            <svg width="10px" height="10px" viewBox="0 0 13 13">
                <path fill="none" stroke="#B8BCC1" stroke-width="2" stroke-linecap="square" d="M6.5,6.5L0.843,0.843L6.5,6.5 l-5.657,5.657L6.5,6.5z M6.5,6.5l5.657,5.657L6.5,6.5l5.657-5.657L6.5,6.5z"/>
            </svg>
        </span>
        <span class="js-toggle--search-city c-search--ico-toggle <?php if (isset($searchQuery['city'])): ?>u-hidden<?php endif; ?>">
            <svg width="13px" height="8px" class="c-ico--down">
                <use href="#ico--down"></use>
            </svg>
            <svg width="13px" height="8px" class="c-ico--up">
                <use href="#ico--up"></use>
            </svg>
        </span>
    </label>

    <label for="search-query" class="c-search--col c-search--col-keyword">
        <svg xmlns="http://www.w3.org/2000/svg" width="20px" height="19px" viewBox="0 0 20 19" class="c-ico--area">
            <path fill="#B8BCC1" d="M18.125,4.5C19.16,4.5,20,5.339,20,6.375v10c0,1.036-0.839,1.875-1.875,1.875H1.875 C0.839,18.25,0,17.411,0,16.375v-10C0,5.339,0.839,4.5,1.875,4.5H6.25V1.688c0-0.518,0.42-0.937,0.937-0.937h5.625 c0.518,0,0.938,0.42,0.938,0.937V4.5H18.125z M7.5,2v2.5h5V2H7.5z M18.75,16.375V10.75H12.5v1.562c0,0.518-0.42,0.937-0.938,0.937 H8.437c-0.518,0-0.938-0.42-0.938-0.937V10.75H1.25v5.625C1.25,16.72,1.53,17,1.875,17h16.25C18.47,17,18.75,16.72,18.75,16.375z M8.75,12h2.5v-1.25h-2.5V12z M18.75,9.5V6.375c0-0.345-0.28-0.625-0.625-0.625H1.875C1.53,5.75,1.25,6.03,1.25,6.375V9.5H18.75z"/>
        </svg>

        <datalist id="search-queries">
<?php
            foreach ( array_merge(getOptions('field'), getOptions('type')) as $option ):
?>
                <option value="<?php echo $option['name']; ?>"><?php echo $option['name']; ?> (<?php echo $option['total']; ?>)</option>
<?php
            endforeach;
?>
        </datalist>
        <input list="search-queries" id="search-query" data-id="<?php echo $langID; ?>" aria-label="<?php _e('Keyword', 'biuro'); ?>" name="s" value="<?php echo (isset($searchQuery['s'])) ? trim(urldecode($searchQuery['s'])) : ''; ?>" placeholder="<?php _e('Keyword', 'biuro'); ?>" class="c-search--input c-search--keyword" />
        <span class="js-clear--search-query c-search--ico-clear <?php if (!isset($searchQuery['s'])): ?>u-hidden<?php endif; ?>">
            <svg width="10px" height="10px" viewBox="0 0 13 13">
                <path fill="none" stroke="#B8BCC1" stroke-width="2" stroke-linecap="square" d="M6.5,6.5L0.843,0.843L6.5,6.5 l-5.657,5.657L6.5,6.5z M6.5,6.5l5.657,5.657L6.5,6.5l5.657-5.657L6.5,6.5z"/>
            </svg>
        </span>
        <span class="js-toggle--search-query c-search--ico-toggle <?php if (isset($searchQuery['s'])): ?>u-hidden<?php endif; ?>">
            <svg width="13px" height="8px" class="c-ico--down">
                <use href="#ico--down"></use>
            </svg>
            <svg width="13px" height="8px" class="c-ico--up">
                <use href="#ico--up"></use>
            </svg>
        </span>
    </label>
    <button class="o-btn c-btn--main <?php if ( is_front_page() ):  ?>c-btn--search<?php else: ?>c-btn--search-small<?php endif; ?>" type="submit" value="1">
        <svg xmlns="http://www.w3.org/2000/svg" width="17px" height="17px" viewBox="0 0 17 17" class="c-ico--search">
            <path fill="#FFFFFF" d="M16.884,15.694c0.156,0.156,0.156,0.408,0,0.564l-0.75,0.75c-0.156,0.156-0.408,0.156-0.564,0 l-4.031-4.031c-0.073-0.076-0.116-0.176-0.116-0.282v-0.438c-1.212,1.046-2.789,1.68-4.516,1.68C3.091,13.938,0,10.846,0,7.031 s3.091-6.906,6.906-6.906c3.815,0,6.906,3.091,6.906,6.906c0,1.727-0.634,3.304-1.68,4.516h0.438c0.106,0,0.206,0.04,0.282,0.116 L16.884,15.694z M6.906,12.344c2.935,0,5.313-2.377,5.313-5.312S9.841,1.719,6.906,1.719c-2.935,0-5.313,2.377-5.313,5.312 S3.971,12.344,6.906,12.344z"/>
        </svg> <span class="c-search--btn-text"><?php _e('Search', 'biuro'); ?></span>
    </button>
</form>

==> dev.biuro-1.18.0.tar.gz: dev.biuro-1.18.0/wp-content/themes/biuro/searchform.php <==
<?php
/**
 * Template for displaying search form in Biuro
 *
 * @package WordPress
 * @subpackage Biuro
 * @since 1.0
 * @version 1.0
 */

global $query_string;

wp_parse_str( $query_string, $searchQuery );

if ( get_post_type() == 'page'  ):
    $pageTerms = getPageTerm(get_post_custom_keys());

    if ($pageTerms):
        if ($pageTerms->taxonomy === 'type' || $pageTerms->taxonomy === 'field'):
            $searchQuery['s'] = $pageTerms->name;
        elseif ($pageTerms->taxonomy === 'city'):
            $searchQuery['city'] = $pageTerms->name;
        endif;
    endif;

endif;


$langs = pll_the_languages(array('raw'=>1));
$langID = $langs[pll_current_language('slug')]['id'];
?>
<form id="search" class="c-search" action="<?php echo home_url(); ?>" method="get">

    <label for="search-city" class="c-search--col c-search--col-location">
        <svg xmlns="http://www.w3.org/2000/svg" width="15px" height="21px" viewBox="0 0 15 21" class="c-ico--location">
            <path fill="#B8BCC1" d="M7.5,4.25c2.068,0,3.75,1.682,3.75,3.75s-1.682,3.75-3.75,3.75S3.75,10.068,3.75,8 S5.432,4.25,7.5,4.25z M7.5,10.5C8.878,10.5,10,9.379,10,8S8.878,5.5,7.5,5.5C6.121,5.5,5,6.622,5,8C5,9.379,6.121,10.5,7.5,10.5z M7.5,0.5C11.642,0.5,15,3.858,15,8c0,3.024-1.054,3.868-6.729,12.096c-0.373,0.538-1.169,0.538-1.542,0C1.054,11.868,0,11.024,0,8 C0,3.858,3.358,0.5,7.5,0.5z M7.5,19.013c5.442-7.87,6.25-8.494,6.25-11.013c0-1.669-0.65-3.239-1.831-4.419 C10.739,2.4,9.169,1.75,7.5,1.75S4.261,2.4,3.081,3.581C1.9,4.761,1.25,6.331,1.25,8C1.25,10.519,2.059,11.144,7.5,19.013z"/>
        </svg>
        <datalist id="search-cities">
<?php
            foreach ( getOptions('city') as $r ):
?>
                <option value="<?php echo $r['name']; ?>"><?php echo $r['name']; ?> (<?php echo $r['total']; ?>)</option>
<?php
            endforeach;
?>
        </datalist>
        <input list="search-cities" id="search-city" data-id="<?php echo $langID; ?>" aria-label="<?php _e('Locations', 'biuro'); ?>" name="city" value="<?php echo (isset($searchQuery['city'])) ? trim(urldecode($searchQuery['city'])) : ''; ?>" placeholder="<?php _e('Locations', 'biuro'); ?>" class="c-search--input c-search--location" />
        <span class="js-clear--search-city c-search--ico-clear <?php if (!isset($searchQuery['city'])): ?>u-hidden<?php endif; ?>">
            <svg width="10px" height="10px" viewBox="0 0 13 13">
                <path fill="none" stroke="#B8BCC1" stroke-width="2" stroke-linecap="square" d="M6.5,6.5L0.843,0.843L6.5,6.5 l-5.657,5.657L6.5,6.5z M6.5,6.5l5.657,5.657L6.5,6.5l5.657-5.657L6.5,6.5z"/>
            </svg>
        </span>
        <span class="js-toggle--search-city c-search--ico-toggle <?php if (isset($searchQuery['city'])): ?>u-hidden<?php endif; ?>">
            <svg width="13px" height="8px" class="c-ico--down">
                <use href="#ico--down"></use>
            </svg>
            <svg width="13px" height="8px" class="c-ico--up">
                <use href="#ico--up"></use>
            </svg>
        </span>
    </label>

    <label for="search-query" class="c-search--col c-search--col-keyword">
        <svg xmlns="http://www.w3.org/2000/svg" width="20px" height="19px" viewBox="0 0 20 19" class="c-ico--area">
            <path fill="#B8BCC1" d="M18.125,4.5C19.16,4.5,20,5.339,20,6.375v10c0,1.036-0.839,1.875-1.875,1.875H1.875 C0.839,18.25,0,17.411,0,16.375v-10C0,5.339,0.839,4.5,1.875,4.5H6.25V1.688c0-0.518,0.42-0.937,0.937-0.937h5.625 c0.518,0,0.938,0.42,0.938,0.937V4.5H18.125z M7.5,2v2.5h5V2H7.5z M18.75,16.375V10.75H12.5v1.562c0,0.518-0.42,0.937-0.938,0.937 H8.437c-0.518,0-0.938-0.42-0.938-0.937V10.75H1.25v5.625C1.25,16.72,1.53,17,1.875,17h16.25C18.47,17,18.75,16.72,18.75,16.375z M8.75,12h2.5v-1.25h-2.5V12z M18.75,9.5V6.375c0-0.345-0.28-0.625-0.625-0.625H1.875C1.53,5.75,1.25,6.03,1.25,6.375V9.5H18.75z"/>
        </svg>

        <datalist id="search-queries">
<?php
            foreach ( array_merge(getOptions('field'), getOptions('type')) as $option ):
?>
                <option value="<?php echo $option['name']; ?>"><?php echo $option['name']; ?> (<?php echo $option['total']; ?>)</option>
<?php
            endforeach;
?>
        </datalist>
        <input list="search-queries" id="search-query" data-id="<?php echo $langID; ?>" aria-label="<?php _e('Keyword', 'biuro'); ?>" name="s" value="<?php echo (isset($searchQuery['s'])) ? trim(urldecode($searchQuery['s'])) : ''; ?>" placeholder="<?php _e('Keyword', 'biuro'); ?>" class="c-search--input c-search--keyword" />
        <span class="js-clear--search-query c-search--ico-clear <?php if (!isset($searchQuery['s'])): ?>u-hidden<?php endif; ?>">
            <svg width="10px" height="10px" viewBox="0 0 13 13">
                <path fill="none" stroke="#B8BCC1" stroke-width="2" stroke-linecap="square" d="M6.5,6.5L0.843,0.843L6.5,6.5 l-5.657,5.657L6.5,6.5z M6.5,6.5l5.657,5.657L6.5,6.5l5.657-5.657L6.5,6.5z"/>
            </svg>
        </span>
        <span class="js-toggle--search-query c-search--ico-toggle <?php if (isset($searchQuery['s'])): ?>u-hidden<?php endif; ?>">
            <svg width="13px" height="8px" class="c-ico--down">
                <use href="#ico--down"></use>
            </svg>
            <svg width="13px" height="8px" class="c-ico--up">
                <use href="#ico--up"></use>
            </svg>
        </span>
    </label>
    <button class="o-btn c-btn--main <?php if ( is_front_page() ):  ?>c-btn--search<?php else: ?>c-btn--search-small<?php endif; ?>" type="submit" value="1" aria-label="<?php _e('Search', 'biuro'); ?>" >
        <svg xmlns="http://www.w3.org/2000/svg" width="17px" height="17px" viewBox="0 0 17 17" class="c-ico--search">
            <path fill="#FFFFFF" d="M16.884,15.694c0.156,0.156,0.156,0.408,0,0.564l-0.75,0.75c-0.156,0.156-0.408,0.156-0.564,0 l-4.031-4.031c-0.073-0.076-0.116-0.176-0.116-0.282v-0.438c-1.212,1.046-2.789,1.68-4.516,1.68C3.091,13.938,0,10.846,0,7.031 s3.091-6.906,6.906-6.906c3.815,0,6.906,3.091,6.906,6.906c0,1.727-0.634,3.304-1.68,4.516h0.438c0.106,0,0.206,0.04,0.282,0.116 L16.884,15.694z M6.906,12.344c2.935,0,5.313-2.377,5.313-5.312S9.841,1.719,6.906,1.719c-2.935,0-5.313,2.377-5.313,5.312 S3.971,12.344,6.906,12.344z"/>
        </svg> <span class="c-search--btn-text"><?php _e('Search', 'biuro'); ?></span>
    </button>
</form>
